--- apps/app_voicemail.c.bak	2010-10-12 22:06:20.737006425 -0400
+++ apps/app_voicemail.c	2010-10-12 23:18:38.588255195 -0400
@@ -1178,6 +1178,50 @@
 	}	
 }
 
+static const char *substitute_escapes(const char *value)
+{
+	char *current;
+
+	/* Add 16 for fudge factor */
+	struct ast_str *str = ast_str_thread_get(&ast_str_thread_global_buf, strlen(value) + 16);
+
+	ast_str_reset(str);
+	
+	/* Substitute strings \r, \n, and \t into the appropriate characters */
+	for (current = (char *) value; *current; current++) {
+		if (*current == '\\') {
+			current++;
+			if (!*current) {
+				ast_log(AST_LOG_NOTICE, "Incomplete escape at end of value.\n");
+				break;
+			}
+			switch (*current) {
+			case 'r':
+				ast_str_append(&str, 0, "\r");
+				break;
+			case 'n':
+#ifdef IMAP_STORAGE
+				if (!str->used || str->str[str->used - 1] != '\r') {
+					ast_str_append(&str, 0, "\r");
+				}
+#endif
+				ast_str_append(&str, 0, "\n");
+				break;
+			case 't':
+				ast_str_append(&str, 0, "\t");
+				break;
+			default:
+				ast_log(AST_LOG_NOTICE, "Substitution routine does not support this character: \\%c\n", *current);
+				break;
+			}
+		} else {
+			ast_str_append(&str, 0, "%c", *current);
+		}
+	}
+
+	return ast_str_buffer(str);
+}
+
 /*!
  * \brief Loads the options specific to a voicemail user.
  * 
@@ -1202,9 +1246,9 @@
 		} else if (!strcasecmp(var->name, "context")) {
 			ast_copy_string(retval->context, var->value, sizeof(retval->context));
 		} else if (!strcasecmp(var->name, "emailsubject")) {
-			retval->emailsubject = ast_strdup(var->value);
+			retval->emailsubject = ast_strdup(substitute_escapes(var->value));
 		} else if (!strcasecmp(var->name, "emailbody")) {
-			retval->emailbody = ast_strdup(var->value);
+			retval->emailbody = ast_strdup(substitute_escapes(var->value));
 #ifdef IMAP_STORAGE
 		} else if (!strcasecmp(var->name, "imapuser")) {
 			ast_copy_string(retval->imapuser, var->value, sizeof(retval->imapuser));
@@ -10613,49 +10657,6 @@
 	AST_LIST_UNLOCK(&zones);
 }
 
-static const char *substitute_escapes(const char *value)
-{
-	char *current;
-
-	/* Add 16 for fudge factor */
-	struct ast_str *str = ast_str_thread_get(&ast_str_thread_global_buf, strlen(value) + 16);
-
-	ast_str_reset(str);
-	
-	/* Substitute strings \r, \n, and \t into the appropriate characters */
-	for (current = (char *) value; *current; current++) {
-		if (*current == '\\') {
-			current++;
-			if (!*current) {
-				ast_log(AST_LOG_NOTICE, "Incomplete escape at end of value.\n");
-				break;
-			}
-			switch (*current) {
-			case 'r':
-				ast_str_append(&str, 0, "\r");
-				break;
-			case 'n':
-#ifdef IMAP_STORAGE
-				if (!str->used || str->str[str->used - 1] != '\r') {
-					ast_str_append(&str, 0, "\r");
-				}
-#endif
-				ast_str_append(&str, 0, "\n");
-				break;
-			case 't':
-				ast_str_append(&str, 0, "\t");
-				break;
-			default:
-				ast_log(AST_LOG_NOTICE, "Substitution routine does not support this character: \\%c\n", *current);
-				break;
-			}
-		} else {
-			ast_str_append(&str, 0, "%c", *current);
-		}
-	}
-
-	return ast_str_buffer(str);
-}
 
 static int load_config(int reload)
 {
